@@ -1,6 +1,7 @@
 import asyncio
 import ipaddress
 import socket
+from typing import Any, List
 from unittest.mock import Mock, patch
 
 import pytest
@@ -39,7 +40,7 @@ def fake_addrinfo(hosts):
         if not hosts:
             raise socket.gaierror
 
-        return list([(None, None, None, None, [h, 0]) for h in hosts])
+        return [(socket.AF_INET, None, socket.SOCK_STREAM, None, [h, 0]) for h in hosts]
 
     return fake
 
@@ -153,17 +154,12 @@ async def test_threaded_negative_lookup() -> None:
         await resolver.resolve("doesnotexist.bla")
 
 
-async def test_close_for_threaded_resolver(loop) -> None:
-    resolver = ThreadedResolver(loop=loop)
-    await resolver.close()
-
-
 async def test_threaded_negative_lookup_with_unknown_result() -> None:
     loop = Mock()
 
     # If compile CPython with `--disable-ipv6` option,
     # we will get an (int, bytes) tuple, instead of a Exception.
-    async def unknown_addrinfo(*args, **kwargs):
+    async def unknown_addrinfo(*args: Any, **kwargs: Any) -> List[Any]:
         return [
             (
                 socket.AF_INET6,
@@ -181,6 +177,9 @@ async def test_threaded_negative_lookup_with_unknown_result() -> None:
         res = await resolver.resolve("www.python.org")
     assert len(res) == 0
 
+
+async def test_close_for_threaded_resolver(loop) -> None:
+    resolver = ThreadedResolver()
     await resolver.close()
 
 
